@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -215,54 +215,6 @@ sub _make_table {
     return $args{_auto}->tag( tag => 'table', attr => $args{table}, cdata => \@cdata );
 }
 
-sub _tag {
-    my %args = @_;
-
-    my $tag;
-    if (ref($args{ $args{tag} }) eq 'HASH') {
-        (my $cdata) = keys %{ $args{ $args{tag} } };
-        (my $attr)  = values %{ $args{ $args{tag} } };
-        $tag = { tag => $args{tag}, attr => $attr, cdata => $cdata };
-    } elsif (defined $args{ $args{tag} } ) {
-        $tag = { tag => $args{tag}, cdata => $args{ $args{tag} } };
-    } 
-    
-    return $tag;
-}
-
-sub _colgroup {
-    my %args = @_;
-
-    my @colgroup;
-    $args{col} = [ $args{col} ] if ref($args{col}) eq 'HASH';
-
-    if (ref($args{col}) eq 'ARRAY') {
-
-        if (ref $args{colgroup} eq 'ARRAY') {
-            @colgroup = map {
-                tag   => 'colgroup',
-                attr  => $_,
-                cdata => [ map { tag => 'col', attr => $_ }, @{ $args{col} } ]
-            }, @{ $args{colgroup} }; 
-        } else {
-            @colgroup = {
-                tag   => 'colgroup',
-                attr  => $args{colgroup},
-                cdata => [ map { tag => 'col', attr => $_ }, @{ $args{col} } ]
-            }; 
-        }
-
-    } else {
-
-        $args{colgroup} = [ $args{colgroup} ] if ref($args{colgroup}) eq 'HASH';
-        if (ref $args{colgroup} eq 'ARRAY') {
-            @colgroup = map { tag => 'colgroup', attr => $_ }, @{ $args{colgroup} };
-        }
-    }
-
-    return @colgroup;
-}
-
 sub _args {
     my ($self,@data,$data,@args,$args);
     $self = shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );
@@ -295,7 +247,12 @@ sub _args {
     return ( $self, $self->{data}, $args ) if $self and $self->{is_cached};
 
     $args->{worksheet} ||= 1;
-    $data = Spreadsheet::HTML::File::Loader::_parse( $args, $data ) if $args->{file};
+    $args->{worksheet} = 1 if $args->{worksheet} < 1;
+    if ($args->{file}) {
+        $data = Spreadsheet::HTML::File::Loader::_parse( $args, $data );
+        unlink $args->{file} if $args->{_unlink};
+    }
+
     $data = [ $data ] unless ref($data) eq 'ARRAY';
     $data = [ $data ] unless ref($data->[0]) eq 'ARRAY';
 
@@ -336,6 +293,53 @@ sub _extrapolate {
     return ( $cdata, $attr );
 }
 
+sub _colgroup {
+    my %args = @_;
+
+    my @colgroup;
+    $args{col} = [ $args{col} ] if ref($args{col}) eq 'HASH';
+
+    if (ref($args{col}) eq 'ARRAY') {
+
+        if (ref $args{colgroup} eq 'ARRAY') {
+            @colgroup = map {
+                tag   => 'colgroup',
+                attr  => $_,
+                cdata => [ map { tag => 'col', attr => $_ }, @{ $args{col} } ]
+            }, @{ $args{colgroup} }; 
+        } else {
+            @colgroup = {
+                tag   => 'colgroup',
+                attr  => $args{colgroup},
+                cdata => [ map { tag => 'col', attr => $_ }, @{ $args{col} } ]
+            }; 
+        }
+
+    } else {
+
+        $args{colgroup} = [ $args{colgroup} ] if ref($args{colgroup}) eq 'HASH';
+        if (ref $args{colgroup} eq 'ARRAY') {
+            @colgroup = map { tag => 'colgroup', attr => $_ }, @{ $args{colgroup} };
+        }
+    }
+
+    return @colgroup;
+}
+
+sub _tag {
+    my %args = @_;
+    my $tag;
+    my $value = $args{ $args{tag} };
+    if (ref $value eq 'HASH') {
+        (my $cdata) = keys %$value;
+        (my $attr)  = values %$value;
+        $tag = { tag => $args{tag}, attr => $attr, cdata => $cdata };
+    } elsif (defined $args{ $args{tag} } ) {
+        $tag = { tag => $args{tag}, cdata => $value };
+    } 
+    return $tag;
+}
+
 # credit: Math::Matrix
 sub _transpose {
     my $data = shift;
@@ -503,9 +507,9 @@ and C<landscape> (headings at left) are all you need.
 
 =head1 PARAMETERS
 
-All methods/procedures accept the same named parameters. With the
-exception of presets, all parameters are initally undefined. If
-they are defined, they may be overrided. You do not necessarily have
+All methods/procedures accept the same named parameters. Some methods
+pre-define parameters on your behalf, for convenience. If these parameters
+are defined, they may be overriden. You do not necessarily have
 to specify C<data>, any bare array references will be collected
 and assigned to C<data>. Just because you can, however, does not
 mean you should. Everything is meant to be convenient.
@@ -532,7 +536,13 @@ are XLS, CSV, JSON, YAML, HTML, GIF, PNG and JPG.
 
   file => 'foo.json'
 
-See L<Spreadsheet::File::Loader> for more on supported file formats.
+C<file> overrides C<data>. You generally either specify C<data>
+or C<file> but not both (unless the file is an image in which the
+two can be combined). 
+
+  data => \@data, file => 'background.png'
+
+See L<Spreadsheet::HTML::File::Loader> for more on supported file formats.
 See L<DBIx::HTML> for formatting your SQL database queries.
 
 If you don't mind having a temp file created on your behalf, you can
@@ -540,6 +550,11 @@ also supply a URI:
 
   file => 'http://your.site.com/path/to/foo.json'
 
+The temp file will be unlinked unless you set the super secret hidden
+param C<_unlink> to zero (0):
+
+  _unlink => 0
+
 =item * C<block>
 
 Integer. Can be supplied in conjunction with C<file> for image
