@@ -27,9 +27,11 @@ sub _parse {
             my @ext = qw( .html .htm .json .jsn .yaml .yml .gif .png .jpg .jpeg .csv .xls .xlsx .sxc .ods );
             my (undef,undef,$suffix) = File::Basename::fileparse( $uri->path, @ext );
             my (undef,$newfile) = File::Temp::tmpnam();
+            unlink $newfile;
             $args->{file} = $newfile . $suffix;
             my $error = LWP::Simple::getstore( $uri->as_string, $args->{file} );
             return [[ "cannot download " . $uri->as_string ],[ "RC code $error" ]] if LWP::Simple::is_error( $error );
+            $args->{_unlink} = defined( $args->{_unlink} ) ? $args->{_unlink} : 1;
         }
     }
 
@@ -283,8 +285,9 @@ sub _parse {
     return [[ "cannot load $file" ],[ 'please install Imager' ]] if $NOT_AVAILABLE;
 
     my $imager = Imager->new;
-    my $image  = $imager->read( file => $file ) or return [[ "cannot load $file" ],[ $imager->errstr ]];
-
+    my @images = $imager->read_multi( file => $file ) or return [[ "cannot load $file" ],[ $imager->errstr ]];
+    my $image = $images[ $args->{worksheet} - 1 ] || $images[0];
+    
     $args->{block} = $args->{block} && $args->{block} =~ /\D/ ? 8 : ($args->{block} || 0) < 1 ? 8 : $args->{block};
     $args->{fill}  = join( 'x', int( $image->getheight / $args->{block} ), int( $image->getwidth / $args->{block} ) );
     $args->{table} ||= { cellspacing => 0, border => 0, cellpadding => 0 };
